@@ -5,6 +5,7 @@
 #include <vector>
 #include <algorithm>
 #include "VoronoiVolume.h"
+#include "Noisify.h"
 
 namespace vivid
 {
@@ -13,7 +14,7 @@ namespace vivid
     class CPointCloud : public CModelComponent{
     public:
         //Constructor and Copy Constructor
-        CPointCloud() : CModelComponent(POINTS) {}
+        CPointCloud(normal_float aOpacity = 1.0, const std::string &arLabel = "") : CModelComponent(aOpacity, arLabel, POINTS) {}
         /**
          * CVoronoiVolume Constructor
          * @param[in] arInputPoints the input point data in x,y,z form.
@@ -23,8 +24,9 @@ namespace vivid
          * @param[in] aVMin the maximum value in arColorField, anything below will be set to aVMax
          * @param[in] arLabel the label of the point cloud
          */
-        CPointCloud(const std::vector<CPoint> &arPoints, const std::string& arColor, normal_float aOpacity, const std::string& arLabel);
-        CPointCloud(const std::vector<CPoint> &arPoints, vector<normal_float> &arColorField, normal_float aFieldMin, normal_float aFieldMax, normal_float aOpacity, const std::string& arLabel);
+        CPointCloud(const std::vector<CPoint> &arPoints, const std::string& arColor = "white", normal_float aOpacity = 1, const std::string &arLabel = "");
+        CPointCloud(const std::vector<CPoint> &arPoints, vector<normal_float> &arColorField, normal_float aFieldMin = 0,
+                    normal_float aFieldMax = 0, normal_float aOpacity = 1, const std::string& arLabel = "");
         CPointCloud(const CPointCloud &arPC) : CModelComponent(arPC){}
         ~CPointCloud(){}
         
@@ -34,7 +36,7 @@ namespace vivid
 
         // Add
         void AddPoints(const std::vector<CPoint> &arPoints, vector<normal_float> &arColorField, normal_float aFieldMin, normal_float aFieldMax);
-
+        inline void Noisify(coord_t aMaxDisplacement) { mPoints = NoisifyPoints(mPoints, aMaxDisplacement); }
         /**
          * CreateSurface using Voronoi algorithm
          * @param[in] arMask a boolean mask of true and false points, used for generating the boundary surface
